Prepares the Kuzushiji-MNIST dataset and optionally downloads it.
kmnist_dataset(
root,
train = TRUE,
transform = NULL,
target_transform = NULL,
download = FALSE
)(string): Root directory of dataset where
KMNIST/processed/training.pt and KMNIST/processed/test.pt exist.
(bool, optional): If TRUE, creates dataset from training.pt,
otherwise from test.pt.
(callable, optional): A function/transform that takes in an
PIL image and returns a transformed version. E.g, transforms.RandomCrop.
(callable, optional): A function/transform that takes in the target and transforms it.
(bool, optional): If true, downloads the dataset from the internet and puts it in root directory. If dataset is already downloaded, it is not downloaded again.